@@ -144,6 +144,21 @@ async def {link.name}(
         refresh=refresh,
         revert_to_first=revert_to_first,
     )
+
+async def {link.name}__count(
+    self,
+    resolver: {link_resolver_name} = None,
+    refresh: bool = False,
+    revert_to_first: bool = False,
+) -> int:
+    rez = resolver or {link_resolver_name}()
+    rez.is_count = True
+    return await self.resolve(
+        edge_name="{link.name}__count",
+        edge_resolver=rez,
+        refresh=refresh,
+        revert_to_first=revert_to_first,
+    )
     """
 
 
@@ -153,6 +168,10 @@ def build_resolver_link_function_str(node_resolver_name: str, link: Link) -> str
 def {link.name}(self, _: T.Optional[{link_resolver_name}] = None, /, ignore_if_subset: bool = False, make_first: bool = False) -> {node_resolver_name}:
     self._nested_resolvers.add("{link.name}", _ or {link_resolver_name}(), ignore_if_subset=ignore_if_subset, make_first=make_first)
     return self
+
+def {link.name}__count(self, _: T.Optional[{link_resolver_name}] = None, /, ignore_if_subset: bool = False, make_first: bool = False) -> {node_resolver_name}:
+    self._nested_resolvers.add("{link.name}__count", _ or {link_resolver_name}(), ignore_if_subset=ignore_if_subset, make_first=make_first)
+    return self
     """
 
 
