@@ -664,6 +664,7 @@ for item in json_array_unpack(raw_data) union ({insert_str}) {given_resolver.to_
         batch: Batch = None,
         given_client: edgedb.AsyncIOClient = None,
         only_one: bool = True,
+        ignore_no_update_registered: bool = True,
     ) -> T.Optional[T.Union[ThisNodeType, T.List[ThisNodeType]]]:
         s, variables = model_dict_to_str(
             d=update_d,
@@ -693,7 +694,7 @@ for item in json_array_unpack(raw_data) union ({insert_str}) {given_resolver.to_
                 variables=variables_to_use,
                 only_one=only_one,
             )
-        if not raw_d:
+        if not raw_d and not ignore_no_update_registered:
             raise NodeException(f"No update for {cls._model_name} was registered.")
         with safe_span(op=f"parse.{cls._model_name}"):
             if only_one:
